@@ -17,6 +17,8 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "config.h"
@@ -25,10 +27,10 @@
 
 #include "peas-extension-set.h"
 
+#include "peas-engine-priv.h"
 #include "peas-i18n-priv.h"
-#include "peas-introspection.h"
-#include "peas-plugin-info.h"
 #include "peas-marshal.h"
+#include "peas-plugin-info.h"
 #include "peas-utils.h"
 
 /**
@@ -47,24 +49,24 @@
  * wish to call specific methods on loading or unloading time.
  *
  * Here is the code for a typical setup of #PeasExtensionSet with
- * [iface@Activatable] as the watched extension point, and [class@Gtk.Window]
+ * ExampleActivatable as the watched extension point, and GtkWindow
  * instances as the target objects:
  *
  * ```c
  * static void
- * on_extension_added (PeasExtensionSet *set,
- *                     PeasPluginInfo   *info,
- *                     PeasActivatable  *activatable)
+ * on_extension_added (PeasExtensionSet   *set,
+ *                     PeasPluginInfo     *info,
+ *                     ExampleActivatable *activatable)
  * {
- *   peas_activatable_activate (activatable);
+ *   example_activatable_activate (activatable);
  * }
  *
  * static void
- * on_extension_removed (PeasExtensionSet *set,
- *                       PeasPluginInfo   *info,
- *                       PeasActivatable  *activatable)
+ * on_extension_removed (PeasExtensionSet   *set,
+ *                       PeasPluginInfo     *info,
+ *                       ExampleActivatable *activatable)
  * {
- *   peas_activatable_deactivate (activatable);
+ *   example_activatable_deactivate (activatable);
  * }
  *
  * PeasExtensionSet *
@@ -73,7 +75,7 @@
  * {
  *   PeasExtensionSet *set;
  *
- *   set = peas_extension_set_new (engine, PEAS_TYPE_ACTIVATABLE,
+ *   set = peas_extension_set_new (engine, EXAMPLE_TYPE_ACTIVATABLE,
  *                                 "object", window, NULL);
  *   peas_extension_set_foreach (set,
  *                               (PeasExtensionSetForeachFunc) on_extension_added,
@@ -89,7 +91,10 @@
 
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 
-struct _PeasExtensionSetPrivate {
+struct _PeasExtensionSet
+{
+  GObject parent_instance;
+
   PeasEngine *engine;
   GType exten_type;
   guint n_parameters;
@@ -101,7 +106,7 @@ struct _PeasExtensionSetPrivate {
 
 typedef struct {
   PeasPluginInfo *info;
-  PeasExtension *exten;
+  GObject *exten;
 } ExtensionItem;
 
 typedef struct {
@@ -133,31 +138,24 @@ static GParamSpec *properties[N_PROPERTIES] = { NULL };
 
 static void list_model_iface_init (GListModelInterface *iface);
 
-G_DEFINE_TYPE_WITH_CODE (PeasExtensionSet, peas_extension_set, G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (PeasExtensionSet)
-                         G_IMPLEMENT_INTERFACE (G_TYPE_LIST_MODEL, list_model_iface_init))
-
-#define GET_PRIV(o) \
-  (peas_extension_set_get_instance_private (o))
+G_DEFINE_FINAL_TYPE_WITH_CODE (PeasExtensionSet, peas_extension_set, G_TYPE_OBJECT,
+                               G_IMPLEMENT_INTERFACE (G_TYPE_LIST_MODEL, list_model_iface_init))
 
 static void
 set_construct_properties (PeasExtensionSet   *set,
                           PeasParameterArray *array)
 {
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
-  guint i;
-
-  priv->n_parameters = array->n_parameters;
+  set->n_parameters = array->n_parameters;
 
   G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-  priv->parameters = g_new0 (GParameter, array->n_parameters);
+  set->parameters = g_new0 (GParameter, array->n_parameters);
   G_GNUC_END_IGNORE_DEPRECATIONS
 
-  for (i = 0; i < array->n_parameters; i++)
+  for (guint i = 0; i < array->n_parameters; i++)
     {
-      priv->parameters[i].name = g_intern_string (array->parameters[i].name);
-      g_value_init (&priv->parameters[i].value, G_VALUE_TYPE (&array->parameters[i].value));
-      g_value_copy (&array->parameters[i].value, &priv->parameters[i].value);
+      set->parameters[i].name = g_intern_string (array->parameters[i].name);
+      g_value_init (&set->parameters[i].value, G_VALUE_TYPE (&array->parameters[i].value));
+      g_value_copy (&array->parameters[i].value, &set->parameters[i].value);
     }
 }
 
@@ -168,15 +166,14 @@ peas_extension_set_set_property (GObject      *object,
                                  GParamSpec   *pspec)
 {
   PeasExtensionSet *set = PEAS_EXTENSION_SET (object);
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
 
   switch (prop_id)
     {
     case PROP_ENGINE:
-      priv->engine = g_value_get_object (value);
+      set->engine = g_value_get_object (value);
       break;
     case PROP_EXTENSION_TYPE:
-      priv->exten_type = g_value_get_gtype (value);
+      set->exten_type = g_value_get_gtype (value);
       break;
     case PROP_CONSTRUCT_PROPERTIES:
       set_construct_properties (set, g_value_get_pointer (value));
@@ -193,15 +190,14 @@ peas_extension_set_get_property (GObject    *object,
                                  GParamSpec *pspec)
 {
   PeasExtensionSet *set = PEAS_EXTENSION_SET (object);
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
 
   switch (prop_id)
     {
     case PROP_ENGINE:
-      g_value_set_object (value, priv->engine);
+      g_value_set_object (value, set->engine);
       break;
     case PROP_EXTENSION_TYPE:
-      g_value_set_gtype (value, priv->exten_type);
+      g_value_set_gtype (value, set->exten_type);
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -212,8 +208,7 @@ static void
 add_extension (PeasExtensionSet *set,
                PeasPluginInfo   *info)
 {
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
-  PeasExtension *exten;
+  GObject *exten;
   ExtensionItem *item;
   guint position;
 
@@ -221,22 +216,22 @@ add_extension (PeasExtensionSet *set,
   if (!peas_plugin_info_is_loaded (info))
     return;
 
-  if (!peas_engine_provides_extension (priv->engine, info,
-                                       priv->exten_type))
+  if (!peas_engine_provides_extension (set->engine, info,
+                                       set->exten_type))
     return;
 
-  exten = peas_engine_create_extensionv (priv->engine, info,
-                                         priv->exten_type,
-                                         priv->n_parameters,
-                                         priv->parameters);
+  exten = _peas_engine_create_extensionv (set->engine, info,
+                                         set->exten_type,
+                                         set->n_parameters,
+                                         set->parameters);
 
   item = g_slice_new (ExtensionItem);
   item->info = info;
   item->exten = exten;
 
-  position = priv->extensions.length;
+  position = set->extensions.length;
 
-  g_queue_push_tail (&priv->extensions, item);
+  g_queue_push_tail (&set->extensions, item);
 
   g_list_model_items_changed (G_LIST_MODEL (set), position, 0, 1);
   g_signal_emit (set, signals[EXTENSION_ADDED], 0, info, exten);
@@ -257,11 +252,9 @@ static void
 remove_extension (PeasExtensionSet *set,
                   PeasPluginInfo   *info)
 {
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
-  GList *l;
   guint position = 0;
 
-  for (l = priv->extensions.head; l != NULL; l = l->next, position++)
+  for (GList *l = set->extensions.head; l != NULL; l = l->next, position++)
     {
       ExtensionItem *item = l->data;
 
@@ -269,7 +262,7 @@ remove_extension (PeasExtensionSet *set,
         continue;
 
       remove_extension_item (set, item);
-      g_queue_delete_link (&priv->extensions, l);
+      g_queue_delete_link (&set->extensions, l);
       g_list_model_items_changed (G_LIST_MODEL (set), position, 1, 0);
       return;
     }
@@ -278,31 +271,33 @@ remove_extension (PeasExtensionSet *set,
 static void
 peas_extension_set_init (PeasExtensionSet *set)
 {
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
-
-  g_queue_init (&priv->extensions);
+  g_queue_init (&set->extensions);
 }
 
 static void
 peas_extension_set_constructed (GObject *object)
 {
   PeasExtensionSet *set = PEAS_EXTENSION_SET (object);
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
-  GList *plugins, *l;
+  guint n_items;
 
-  if (priv->engine == NULL)
-    priv->engine = peas_engine_get_default ();
+  if (set->engine == NULL)
+    set->engine = peas_engine_get_default ();
 
-  g_object_ref (priv->engine);
+  g_object_ref (set->engine);
 
-  plugins = (GList *) peas_engine_get_plugin_list (priv->engine);
-  for (l = plugins; l; l = l->next)
-    add_extension (set, (PeasPluginInfo *) l->data);
+  n_items = g_list_model_get_n_items (G_LIST_MODEL (set->engine));
 
-  g_signal_connect_object (priv->engine, "load-plugin",
+  for (guint i = 0; i < n_items; i++)
+    {
+      PeasPluginInfo *info = g_list_model_get_item (G_LIST_MODEL (set->engine), i);
+      add_extension (set, info);
+      g_object_unref (info);
+    }
+
+  g_signal_connect_object (set->engine, "load-plugin",
                            G_CALLBACK (add_extension), set,
                            G_CONNECT_AFTER | G_CONNECT_SWAPPED);
-  g_signal_connect_object (priv->engine, "unload-plugin",
+  g_signal_connect_object (set->engine, "unload-plugin",
                            G_CALLBACK (remove_extension), set,
                            G_CONNECT_SWAPPED);
 
@@ -313,50 +308,29 @@ static void
 peas_extension_set_dispose (GObject *object)
 {
   PeasExtensionSet *set = PEAS_EXTENSION_SET (object);
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
-  GList *l;
 
-  if (priv->extensions.length > 0)
+  if (set->extensions.length > 0)
     {
-      for (l = priv->extensions.tail; l != NULL; l = l->prev)
-        remove_extension_item (set, (ExtensionItem *) l->data);
+      for (const GList *l = set->extensions.tail; l != NULL; l = l->prev)
+        remove_extension_item (set, l->data);
 
-      g_queue_clear (&priv->extensions);
+      g_queue_clear (&set->extensions);
     }
 
-  if (priv->parameters != NULL)
+  if (set->parameters != NULL)
     {
-      while (priv->n_parameters-- > 0)
-        g_value_unset (&priv->parameters[priv->n_parameters].value);
+      while (set->n_parameters-- > 0)
+        g_value_unset (&set->parameters[set->n_parameters].value);
 
-      g_free (priv->parameters);
-      priv->parameters = NULL;
+      g_free (set->parameters);
+      set->parameters = NULL;
     }
 
-  g_clear_object (&priv->engine);
+  g_clear_object (&set->engine);
 
   G_OBJECT_CLASS (peas_extension_set_parent_class)->dispose (object);
 }
 
-static gboolean
-peas_extension_set_call_real (PeasExtensionSet *set,
-                              const gchar      *method_name,
-                              GIArgument       *args)
-{
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
-  gboolean ret = TRUE;
-  GList *l;
-  GIArgument dummy;
-
-  for (l = priv->extensions.head; l != NULL; l = l->next)
-    {
-      ExtensionItem *item = (ExtensionItem *) l->data;
-      ret = peas_extension_callv (item->exten, method_name, args, &dummy) && ret;
-    }
-
-  return ret;
-}
-
 static void
 peas_extension_set_class_init (PeasExtensionSetClass *klass)
 {
@@ -368,13 +342,11 @@ peas_extension_set_class_init (PeasExtensionSetClass *klass)
   object_class->constructed = peas_extension_set_constructed;
   object_class->dispose = peas_extension_set_dispose;
 
-  klass->call = peas_extension_set_call_real;
-
   /**
    * PeasExtensionSet::extension-added:
    * @set: A #PeasExtensionSet.
    * @info: A #PeasPluginInfo.
-   * @exten: A #PeasExtension.
+   * @extension: A #PeasExtension.
    *
    * Emitted when a new extension has been added to the #PeasExtensionSet.
    *
@@ -390,19 +362,22 @@ peas_extension_set_class_init (PeasExtensionSetClass *klass)
     g_signal_new (I_("extension-added"),
                   the_type,
                   G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (PeasExtensionSetClass, extension_added),
+                  0,
                   NULL, NULL,
-                  peas_cclosure_marshal_VOID__BOXED_OBJECT,
+                  peas_cclosure_marshal_VOID__OBJECT_OBJECT,
                   G_TYPE_NONE,
                   2,
                   PEAS_TYPE_PLUGIN_INFO | G_SIGNAL_TYPE_STATIC_SCOPE,
-                  PEAS_TYPE_EXTENSION);
+                  G_TYPE_OBJECT);
+  g_signal_set_va_marshaller (signals[EXTENSION_ADDED],
+                              G_TYPE_FROM_CLASS (klass),
+                              peas_cclosure_marshal_VOID__OBJECT_OBJECTv);
 
   /**
    * PeasExtensionSet::extension-removed:
    * @set: A #PeasExtensionSet.
    * @info: A #PeasPluginInfo.
-   * @exten: A #PeasExtension.
+   * @extension: A #PeasExtension.
    *
    * Emitted when a new extension is about to be removed from the
    * #PeasExtensionSet.
@@ -412,20 +387,23 @@ peas_extension_set_class_init (PeasExtensionSetClass *klass)
    *
    * You should connect to this signal in order to clean up the extensions
    * when their plugin is unload. Note that this signal is not fired for the
-   * [alias@Extension] instances still available when the #PeasExtensionSet
+   * [class@GObject.Object] instances still available when the #PeasExtensionSet
    * instance is destroyed. You should clean those up by yourself.
    */
   signals[EXTENSION_REMOVED] =
     g_signal_new (I_("extension-removed"),
                   the_type,
                   G_SIGNAL_RUN_LAST,
-                  G_STRUCT_OFFSET (PeasExtensionSetClass, extension_removed),
+                  0,
                   NULL, NULL,
-                  peas_cclosure_marshal_VOID__BOXED_OBJECT,
+                  peas_cclosure_marshal_VOID__OBJECT_OBJECT,
                   G_TYPE_NONE,
                   2,
                   PEAS_TYPE_PLUGIN_INFO | G_SIGNAL_TYPE_STATIC_SCOPE,
-                  PEAS_TYPE_EXTENSION);
+                  G_TYPE_OBJECT);
+  g_signal_set_va_marshaller (signals[EXTENSION_REMOVED],
+                              G_TYPE_FROM_CLASS (klass),
+                              peas_cclosure_marshal_VOID__OBJECT_OBJECTv);
 
   properties[PROP_ENGINE] =
     g_param_spec_object ("engine",
@@ -461,23 +439,20 @@ peas_extension_set_class_init (PeasExtensionSetClass *klass)
  * @set: A #PeasExtensionSet
  * @info: a #PeasPluginInfo
  *
- * Returns the [alias@Extension] object corresponding to @info.
+ * Returns the [class@GObject.Object] object corresponding to @info.
  *
  * If the plugin doesn't provide such an extension, it returns %NULL.
  *
- * Returns: (transfer none) (nullable): a reference to a #PeasExtension
+ * Returns: (transfer none) (nullable): a reference to a #GObject
  */
-PeasExtension *
+GObject *
 peas_extension_set_get_extension (PeasExtensionSet *set,
                                   PeasPluginInfo   *info)
 {
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
-  GList *l;
-
   g_return_val_if_fail (PEAS_IS_EXTENSION_SET (set), NULL);
   g_return_val_if_fail (info != NULL, NULL);
 
-  for (l = priv->extensions.head; l != NULL; l = l->next)
+  for (const GList *l = set->extensions.head; l != NULL; l = l->next)
     {
       ExtensionItem *item = l->data;
 
@@ -488,129 +463,23 @@ peas_extension_set_get_extension (PeasExtensionSet *set,
   return NULL;
 }
 
-/**
- * peas_extension_set_call: (skip)
- * @set: A #PeasExtensionSet.
- * @method_name: the name of the method that should be called.
- * @...: arguments for the method.
- *
- * Call a method on all the [alias@Extension] instances contained in @set.
- *
- * Deprecated: 1.2: Use [method@ExtensionSet.foreach] instead.
- *
- * Returns: %TRUE on successful call.
- */
-gboolean
-peas_extension_set_call (PeasExtensionSet *set,
-                         const gchar      *method_name,
-                         ...)
-{
-  va_list args;
-  gboolean result;
-
-  g_return_val_if_fail (PEAS_IS_EXTENSION_SET (set), FALSE);
-  g_return_val_if_fail (method_name != NULL, FALSE);
-
-  va_start (args, method_name);
-  result = peas_extension_set_call_valist (set, method_name, args);
-  va_end (args);
-
-  return result;
-}
-
-/**
- * peas_extension_set_call_valist: (skip)
- * @set: A #PeasExtensionSet.
- * @method_name: the name of the method that should be called.
- * @va_args: the arguments for the method.
- *
- * Call a method on all the [alias@Extension] instances contained in @set.
- *
- * Deprecated: 1.2: Use [class@ExtensionSet.foreach] instead.
- *
- * Returns: %TRUE on successful call.
- */
-gboolean
-peas_extension_set_call_valist (PeasExtensionSet *set,
-                                const gchar      *method_name,
-                                va_list           va_args)
-{
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
-  GICallableInfo *callable_info;
-  GIArgument *args;
-  gint n_args;
-
-  g_return_val_if_fail (PEAS_IS_EXTENSION_SET (set), FALSE);
-  g_return_val_if_fail (method_name != NULL, FALSE);
-
-  callable_info = peas_gi_get_method_info (priv->exten_type, method_name);
-
-  if (callable_info == NULL)
-    {
-      g_warning ("Method '%s.%s' was not found",
-                 g_type_name (priv->exten_type), method_name);
-      return FALSE;
-    }
-
-  n_args = gi_callable_info_get_n_args (callable_info);
-  g_return_val_if_fail (n_args >= 0, FALSE);
-
-  args = g_newa (GIArgument, n_args);
-  peas_gi_valist_to_arguments (callable_info, va_args, args, NULL);
-
-  gi_base_info_unref ((GIBaseInfo *) callable_info);
-
-  return peas_extension_set_callv (set, method_name, args);
-}
-
-/**
- * peas_extension_set_callv: (skip)
- * @set: A #PeasExtensionSet.
- * @method_name: the name of the method that should be called.
- * @args: the arguments for the method.
- *
- * Call a method on all the [alias@Extension] instances contained in @set.
- *
- * Returns: %TRUE on successful call.
- *
- * Deprecated: 1.2: Use [method@ExtensionSet.foreach] instead.
- */
-gboolean
-peas_extension_set_callv (PeasExtensionSet *set,
-                          const gchar      *method_name,
-                          GIArgument       *args)
-{
-  PeasExtensionSetClass *klass;
-
-  g_return_val_if_fail (PEAS_IS_EXTENSION_SET (set), FALSE);
-  g_return_val_if_fail (method_name != NULL, FALSE);
-
-  klass = PEAS_EXTENSION_SET_GET_CLASS (set);
-  return klass->call (set, method_name, args);
-}
-
 /**
  * peas_extension_set_foreach:
  * @set: A #PeasExtensionSet.
  * @func: (scope call): A function call for each extension.
  * @data: Optional data to be passed to the function or %NULL.
  *
- * Calls @func for each [alias@Extension].
- *
- * Since: 1.2
+ * Calls @func for each [class@GObject.Object].
  */
 void
 peas_extension_set_foreach (PeasExtensionSet            *set,
                             PeasExtensionSetForeachFunc  func,
                             gpointer                     data)
 {
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
-  GList *l;
-
   g_return_if_fail (PEAS_IS_EXTENSION_SET (set));
   g_return_if_fail (func != NULL);
 
-  for (l = priv->extensions.head; l != NULL; l = l->next)
+  for (const GList *l = set->extensions.head; l != NULL; l = l->next)
     {
       ExtensionItem *item = (ExtensionItem *) l->data;
 
@@ -619,25 +488,7 @@ peas_extension_set_foreach (PeasExtensionSet            *set,
 }
 
 G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-/**
- * peas_extension_set_newv: (skip)
- * @engine: (allow-none): A #PeasEngine, or %NULL.
- * @exten_type: the extension #GType.
- * @n_parameters: the length of the @parameters array.
- * @parameters: (array length=n_parameters): an array of #GParameter.
- *
- * Create a new #PeasExtensionSet for the @exten_type extension type.
- *
- * If @engine is %NULL, then the default engine will be used.
- *
- * Since libpeas 1.22, @exten_type can be an Abstract [alias@GObject.Type]
- * and not just an Interface [alias@GObject.Type].
- *
- * See [ctor@ExtensionSet.new] for more information.
- *
- * Returns: (transfer full): a new instance of #PeasExtensionSet.
- */
-PeasExtensionSet *
+static PeasExtensionSet *
 peas_extension_set_newv (PeasEngine *engine,
                          GType       exten_type,
                          guint       n_parameters,
@@ -668,20 +519,15 @@ peas_extension_set_newv (PeasEngine *engine,
  *
  * If @engine is %NULL, then the default engine will be used.
  *
- * Since libpeas 1.22, @exten_type can be an Abstract [alias@GObject.Type]
- * and not just an Interface [alias@GObject.Type].
- *
  * See [ctor@ExtensionSet.new] for more information.
  *
  * Returns: (transfer full): a new instance of #PeasExtensionSet.
- *
- * Since 1.24.0
  */
 PeasExtensionSet *
 peas_extension_set_new_with_properties (PeasEngine    *engine,
                                         GType          exten_type,
                                         guint          n_properties,
-                                        const gchar  **prop_names,
+                                        const char   **prop_names,
                                         const GValue  *prop_values)
 {
   PeasExtensionSet *ret;
@@ -734,18 +580,15 @@ peas_extension_set_new_with_properties (PeasEngine    *engine,
  *
  * If @engine is %NULL, then the default engine will be used.
  *
- * Since libpeas 1.22, @exten_type can be an Abstract [alias@GObject.Type]
- * and not just an Interface [alias@GObject.Type].
- *
  * See [ctor@ExtensionSet.new] for more information.
  *
  * Returns: a new instance of #PeasExtensionSet.
  */
 PeasExtensionSet *
-peas_extension_set_new_valist (PeasEngine  *engine,
-                               GType        exten_type,
-                               const gchar *first_property,
-                               va_list      var_args)
+peas_extension_set_new_valist (PeasEngine *engine,
+                               GType       exten_type,
+                               const char *first_property,
+                               va_list     var_args)
 {
   GParameter *parameters;
   guint n_parameters;
@@ -771,7 +614,6 @@ peas_extension_set_new_valist (PeasEngine  *engine,
 
   return set;
 }
-G_GNUC_END_IGNORE_DEPRECATIONS
 
 /**
  * peas_extension_set_new: (skip)
@@ -792,17 +634,14 @@ G_GNUC_END_IGNORE_DEPRECATIONS
  *
  * If @engine is %NULL, then the default engine will be used.
  *
- * Since libpeas 1.22, @exten_type can be an Abstract [alias@GObject.Type]
- * and not just an Interface [alias@GObject.Type].
- *
  * See [method@Engine.create_extension] for more information.
  *
  * Returns: a new instance of #PeasExtensionSet.
  */
 PeasExtensionSet *
-peas_extension_set_new (PeasEngine  *engine,
-                        GType        exten_type,
-                        const gchar *first_property,
+peas_extension_set_new (PeasEngine *engine,
+                        GType       exten_type,
+                        const char *first_property,
                         ...)
 {
   va_list var_args;
@@ -818,14 +657,14 @@ peas_extension_set_new (PeasEngine  *engine,
 
   return set;
 }
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 static guint
 peas_extension_set_get_n_items (GListModel *model)
 {
   PeasExtensionSet *set = PEAS_EXTENSION_SET (model);
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
 
-  return priv->extensions.length;
+  return set->extensions.length;
 }
 
 static gpointer
@@ -833,12 +672,11 @@ peas_extension_set_get_item (GListModel *model,
                              guint       position)
 {
   PeasExtensionSet *set = PEAS_EXTENSION_SET (model);
-  PeasExtensionSetPrivate *priv = GET_PRIV (set);
 
-  if (position >= priv->extensions.length)
+  if (position >= set->extensions.length)
     return NULL;
 
-  return g_object_ref (g_queue_peek_nth (&priv->extensions, position));
+  return g_object_ref (g_queue_peek_nth (&set->extensions, position));
 }
 
 static GType
@@ -854,4 +692,3 @@ list_model_iface_init (GListModelInterface *iface)
   iface->get_item = peas_extension_set_get_item;
   iface->get_n_items = peas_extension_set_get_n_items;
 }
-
