@@ -17,26 +17,27 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
-#include "libpeas/peas.h"
-#include "libpeas/peas-plugin-info-priv.h"
+#include "libpeas.h"
+#include "peas-plugin-info-priv.h"
 
 #include "testing/testing-extension.h"
 #include "introspection/introspection-base.h"
 #include "plugins/embedded/embedded-plugin.h"
 #include "plugins/embedded/embedded-resources.h"
 
+#include "introspection/introspection-activatable.h"
 
 static void
 test_extension_c_embedded (PeasEngine *engine)
 {
   PeasPluginInfo *info;
-  PeasExtension *extension;
+  GObject *extension;
 
   info = peas_engine_get_plugin_info (engine, "embedded");
 
@@ -66,7 +67,7 @@ test_extension_c_embedded (PeasEngine *engine)
   g_assert (peas_plugin_info_is_loaded (info));
 
   extension = peas_engine_create_extension (engine, info,
-                                            PEAS_TYPE_ACTIVATABLE,
+                                            INTROSPECTION_TYPE_ACTIVATABLE,
                                             NULL);
 
   g_assert (TESTING_IS_EMBEDDED_PLUGIN (extension));
@@ -92,13 +93,13 @@ static void
 test_extension_c_instance_refcount (PeasEngine     *engine,
                                     PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
 
   extension = peas_engine_create_extension (engine, info,
                                             INTROSPECTION_TYPE_BASE,
                                             NULL);
 
-  g_assert (PEAS_IS_EXTENSION (extension));
+  g_assert (G_IS_OBJECT (extension));
 
   /* The refcount of the returned object should be 1:
    *  - one ref for the PeasExtension
@@ -126,7 +127,7 @@ test_extension_c_local_linkage (PeasEngine     *engine,
                                 PeasPluginInfo *info)
 {
   PeasPluginInfo *loadable_info;
-  PeasExtension *c_extension, *loadable_extension;
+  GObject *c_extension, *loadable_extension;
   gpointer c_global_symbol, loadable_global_symbol;
 
   loadable_info = peas_engine_get_plugin_info (engine, "loadable");
@@ -136,11 +137,11 @@ test_extension_c_local_linkage (PeasEngine     *engine,
                                               INTROSPECTION_TYPE_BASE,
                                               NULL);
   loadable_extension = peas_engine_create_extension (engine, loadable_info,
-                                                     PEAS_TYPE_ACTIVATABLE,
+                                                     INTROSPECTION_TYPE_ACTIVATABLE,
                                                      NULL);
 
-  g_assert (PEAS_IS_EXTENSION (c_extension));
-  g_assert (PEAS_IS_EXTENSION (loadable_extension));
+  g_assert (G_IS_OBJECT (c_extension));
+  g_assert (G_IS_OBJECT (loadable_extension));
   g_assert (c_extension != loadable_extension);
 
   g_object_get (c_extension,
@@ -186,11 +187,6 @@ main (int   argc,
   /* Only test the basics */
   testing_extension_basic ("c");
 
-  /* We still need to add the callable tests
-   * because of peas_extension_call()
-   */
-  testing_extension_callable ("c");
-
   EXTENSION_TEST (c, "embedded", embedded);
   EXTENSION_TEST (c, "embedded-missing-symbol", embedded_missing_symbol);
   EXTENSION_TEST (c, "instance-refcount", instance_refcount);
