@@ -17,19 +17,19 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include <lua.h>
 #include <lauxlib.h>
 
-#include <libpeas/peas-activatable.h>
 #include "libpeas/peas-engine-priv.h"
 
 #include "testing/testing-extension.h"
+#include "introspection/introspection-activatable.h"
 #include "introspection/introspection-base.h"
 
 
@@ -42,21 +42,21 @@ set_garbage_collector_state (PeasEngine     *engine,
                              PeasPluginInfo *info,
                              gboolean        start)
 {
-  PeasExtension *extension;
+  GObject *extension;
 
   extension = peas_engine_create_extension (engine, info,
-                                            PEAS_TYPE_ACTIVATABLE,
+                                            INTROSPECTION_TYPE_ACTIVATABLE,
                                             NULL);
 
   if (start)
     {
       /* collectgarbage('restart') */
-      peas_activatable_activate (PEAS_ACTIVATABLE (extension));
+      introspection_activatable_activate (INTROSPECTION_ACTIVATABLE (extension));
     }
   else
     {
       /* collectgarbage('stop') */
-      peas_activatable_deactivate (PEAS_ACTIVATABLE (extension));
+      introspection_activatable_deactivate (INTROSPECTION_ACTIVATABLE (extension));
     }
 
   g_object_unref (extension);
@@ -66,16 +66,16 @@ static void
 test_extension_lua_instance_refcount (PeasEngine     *engine,
                                       PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
 
   set_garbage_collector_state (engine, info, FALSE);
 
   extension = peas_engine_create_extension (engine, info,
-                                            PEAS_TYPE_ACTIVATABLE,
+                                            INTROSPECTION_TYPE_ACTIVATABLE,
                                             NULL);
   g_object_add_weak_pointer (extension, (gpointer *) &extension);
 
-  g_assert (PEAS_IS_EXTENSION (extension));
+  g_assert (G_IS_OBJECT (extension));
 
   /* The Lua wrapper created around the extension
    * object should have increased its refcount by 1.
@@ -87,7 +87,7 @@ test_extension_lua_instance_refcount (PeasEngine     *engine,
   g_assert_cmpint (G_OBJECT (extension)->ref_count, ==, 1);
 
   /* Create a new Lua wrapper around the extension */
-  peas_activatable_update_state (PEAS_ACTIVATABLE (extension));
+  introspection_activatable_update_state (INTROSPECTION_ACTIVATABLE (extension));
   g_assert_cmpint (G_OBJECT (extension)->ref_count, ==, 2);
 
   /* The Lua wrapper still exists */
@@ -105,7 +105,7 @@ static void
 test_extension_lua_activatable_subject_refcount (PeasEngine     *engine,
                                                  PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
   GObject *object;
 
   set_garbage_collector_state (engine, info, FALSE);
@@ -120,12 +120,12 @@ test_extension_lua_activatable_subject_refcount (PeasEngine     *engine,
 
   /* We pre-create the wrapper to make it easier to check reference count */
   extension = peas_engine_create_extension (engine, info,
-                                            PEAS_TYPE_ACTIVATABLE,
+                                            INTROSPECTION_TYPE_ACTIVATABLE,
                                             "object", object,
                                             NULL);
   g_object_add_weak_pointer (extension, (gpointer *) &extension);
 
-  g_assert (PEAS_IS_EXTENSION (extension));
+  g_assert (G_IS_OBJECT (extension));
 
   /* The Lua wrapper created around our dummy
    * object should have increased its refcount by 1.
@@ -170,14 +170,9 @@ main (int   argc,
   /* Only test the basics */
   testing_extension_basic ("lua5.1");
 
-  /* We still need to add the callable tests
-   * because of peas_extension_call()
-   */
-  testing_extension_callable ("lua5.1");
-
 #undef EXTENSION_TEST
 #undef EXTENSION_TEST_FUNC
-  
+
 #define EXTENSION_TEST(loader, path, func) \
   testing_extension_add (EXTENSION_TEST_NAME (loader, path), \
                          (gpointer) test_extension_lua_##func)
