@@ -18,44 +18,36 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include <pygobject.h>
 
-#include <libpeas/peas-activatable.h>
 #include "libpeas/peas-engine-priv.h"
 
 #include "testing/testing-extension.h"
+
+#include "introspection/introspection-activatable.h"
 #include "introspection/introspection-base.h"
 
-
-#if PY_VERSION_HEX < 0x03000000
-#define PY_LOADER       python
-#define ALT_PY_LOADER   python3
-#else
-#define PY_LOADER       python3
-#define ALT_PY_LOADER   python
-#endif
-
-#define PY_LOADER_STR       G_STRINGIFY (PY_LOADER)
-#define ALT_PY_LOADER_STR   G_STRINGIFY (ALT_PY_LOADER)
+#define PY_LOADER      python
+#define PY_LOADER_STR  G_STRINGIFY (PY_LOADER)
 
 
 static void
 test_extension_py_instance_refcount (PeasEngine     *engine,
                                      PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
 
   extension = peas_engine_create_extension (engine, info,
                                             INTROSPECTION_TYPE_BASE,
                                             NULL);
 
-  g_assert (PEAS_IS_EXTENSION (extension));
+  g_assert (G_IS_OBJECT (extension));
 
   g_object_add_weak_pointer (extension, (gpointer *) &extension);
 
@@ -69,7 +61,7 @@ static void
 test_extension_py_activatable_subject_refcount (PeasEngine     *engine,
                                                 PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
   GObject *object;
   PyObject *wrapper;
 
@@ -81,11 +73,11 @@ test_extension_py_activatable_subject_refcount (PeasEngine     *engine,
 
   /* we pre-create the wrapper to make it easier to check reference count */
   extension = peas_engine_create_extension (engine, info,
-                                            PEAS_TYPE_ACTIVATABLE,
+                                            INTROSPECTION_TYPE_ACTIVATABLE,
                                             "object", object,
                                             NULL);
 
-  g_assert (PEAS_IS_EXTENSION (extension));
+  g_assert (G_IS_OBJECT (extension));
 
   /* The python wrapper created around our dummy object should have increased
    * its refcount by 1.
@@ -176,49 +168,6 @@ test_extension_py_already_initialized_subprocess (void)
   Py_Finalize ();
 }
 
-#if ENABLE_PYTHON2 && ENABLE_PYTHON3
-static void
-test_extension_py_mixed_python (void)
-{
-  GTestSubprocessFlags flags = 0;
-
-  /* Loading both Python 2 and Python 3 might cause
-   * the linker to spew warnings, i.e. on OpenBSD, so
-   * only inherit standard error when debugging
-   */
-  if (g_getenv ("PEAS_DEBUG") != NULL)
-    flags |= G_TEST_SUBPROCESS_INHERIT_STDERR;
-
-  g_test_trap_subprocess (EXTENSION_TEST_NAME (PY_LOADER,
-                                               "mixed-python/subprocess"),
-                          0, flags);
-  g_test_trap_assert_passed ();
-}
-
-static void
-test_extension_py_mixed_python_subprocess (void)
-{
-  PeasEngine *engine;
-  PeasPluginInfo *info;
-
-  testing_util_push_log_hook ("*mix incompatible Python versions*");
-  testing_util_push_log_hook ("*check the installation*");
-  testing_util_push_log_hook ("*'" ALT_PY_LOADER_STR
-                              "' is not a valid PeasPluginLoader*");
-
-  g_setenv ("PEAS_ALLOW_CONFLICTING_LOADERS", "1", TRUE);
-
-  engine = testing_engine_new ();
-  peas_engine_enable_loader (engine, ALT_PY_LOADER_STR);
-
-  info = peas_engine_get_plugin_info (engine, "extension-" ALT_PY_LOADER_STR);
-
-  g_assert (!peas_engine_load_plugin (engine, info));
-
-  testing_engine_free (engine);
-}
-#endif
-
 int
 main (int   argc,
       char *argv[])
@@ -228,14 +177,9 @@ main (int   argc,
   /* Only test the basics */
   testing_extension_basic (PY_LOADER_STR);
 
-  /* We still need to add the callable tests
-   * because of peas_extension_call()
-   */
-  testing_extension_callable (PY_LOADER_STR);
-
 #undef EXTENSION_TEST
 #undef EXTENSION_TEST_FUNC
-  
+
 #define EXTENSION_TEST(loader, path, func) \
   testing_extension_add (EXTENSION_TEST_NAME (loader, path), \
                          (gpointer) test_extension_py_##func)
@@ -254,11 +198,5 @@ main (int   argc,
   EXTENSION_TEST_FUNC (PY_LOADER, "already-initialized/subprocess",
                        already_initialized_subprocess);
 
-#if ENABLE_PYTHON2 && ENABLE_PYTHON3
-  EXTENSION_TEST_FUNC (PY_LOADER, "mixed-python", mixed_python);
-  EXTENSION_TEST_FUNC (PY_LOADER, "mixed-python/subprocess",
-                       mixed_python_subprocess);
-#endif
-
   return testing_extension_run_tests ();
 }
