@@ -17,17 +17,19 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include <stdlib.h>
 
 #include <glib.h>
 #include <glib-object.h>
-#include <libpeas/peas.h>
+#include <libpeas.h>
+
+#include "introspection-activatable.h"
 
 #include "testing/testing.h"
 
@@ -38,15 +40,15 @@ struct _TestFixture {
 };
 
 /* Have dependencies before the plugin that requires them */
-static const gchar *loadable_plugins[] = {
+static const char *loadable_plugins[] = {
   "loadable", "has-dep", "self-dep"
 };
 
 static void
 extension_added_cb (PeasExtensionSet *extension_set,
                     PeasPluginInfo   *info,
-                    PeasExtension    *extension,
-                    gint             *active)
+                    GObject    *extension,
+                    int             *active)
 {
   ++(*active);
 }
@@ -54,28 +56,28 @@ extension_added_cb (PeasExtensionSet *extension_set,
 static void
 extension_removed_cb (PeasExtensionSet *extension_set,
                       PeasPluginInfo   *info,
-                      PeasExtension    *extension,
-                      gint             *active)
+                      GObject    *extension,
+                      int             *active)
 {
   --(*active);
 }
 
 static PeasExtensionSet *
 testing_extension_set_new (PeasEngine *engine,
-                           gint       *active)
+                           int       *active)
 {
-  gint i;
+  int i;
   PeasPluginInfo *info;
   PeasExtensionSet *extension_set;
 
   extension_set = peas_extension_set_new (engine,
-                                          PEAS_TYPE_ACTIVATABLE,
+                                          INTROSPECTION_TYPE_ACTIVATABLE,
                                           "object", NULL,
                                           NULL);
 
   if (active == NULL)
     {
-      active = g_new (gint, 1);
+      active = g_new (int, 1);
       g_object_set_data_full (G_OBJECT (extension_set),
                               "testing-extension-set-active", active,
                               g_free);
@@ -104,7 +106,7 @@ testing_extension_set_new (PeasEngine *engine,
       g_assert (peas_engine_load_plugin (engine, info));
     }
 
-  /* Load a plugin that does not provide a PeasActivatable */
+  /* Load a plugin that does not provide a IntrospectionActivatable */
   info = peas_engine_get_plugin_info (engine, "extension-c");
   g_assert (peas_engine_load_plugin (engine, info));
 
@@ -140,7 +142,7 @@ test_extension_set_create_valid (PeasEngine *engine)
   PeasExtensionSet *extension_set;
 
   extension_set = peas_extension_set_new (engine,
-                                          PEAS_TYPE_ACTIVATABLE,
+                                          INTROSPECTION_TYPE_ACTIVATABLE,
                                           "object", NULL,
                                           NULL);
 
@@ -150,10 +152,11 @@ test_extension_set_create_valid (PeasEngine *engine)
 static void
 valid_extension_added_cb (PeasExtensionSet *extension_set,
                           PeasPluginInfo   *info,
-                          PeasExtension    *extension,
+                          GObject    *extension,
                           GObject          **obj_ptr)
 {
-  g_object_get (PEAS_ACTIVATABLE (extension), "object", obj_ptr, NULL);
+  g_clear_object (obj_ptr);
+  g_object_get (INTROSPECTION_ACTIVATABLE (extension), "object", obj_ptr, NULL);
 }
 
 static void
@@ -162,15 +165,16 @@ test_extension_set_create_valid_with_properties (PeasEngine *engine)
   PeasPluginInfo *info;
   PeasExtensionSet *extension_set;
   GValue prop_value = G_VALUE_INIT;
-  GObject *obj, *obj_cmp;
-  const gchar *prop_names[1] = { "object" };
+  GObject *obj;
+  GObject *obj_cmp = NULL;
+  const char *prop_names[1] = { "object" };
 
   obj = g_object_new (G_TYPE_OBJECT, NULL);
   g_value_init (&prop_value, G_TYPE_OBJECT);
   g_value_set_object (&prop_value, obj);
 
   extension_set = peas_extension_set_new_with_properties (engine,
-                                                          PEAS_TYPE_ACTIVATABLE,
+                                                          INTROSPECTION_TYPE_ACTIVATABLE,
                                                           G_N_ELEMENTS (prop_names),
                                                           prop_names,
                                                           &prop_value);
@@ -184,8 +188,11 @@ test_extension_set_create_valid_with_properties (PeasEngine *engine)
   g_assert (obj == obj_cmp);
 
   g_assert (PEAS_IS_EXTENSION_SET (extension_set));
-  g_object_unref (extension_set);
+  g_assert_finalize_object (extension_set);
   g_value_unset (&prop_value);
+
+  g_object_unref (obj_cmp);
+  g_assert_finalize_object (obj);
 }
 
 
@@ -195,7 +202,7 @@ test_extension_set_create_invalid (PeasEngine *engine)
   PeasExtensionSet *extension_set;
 
   testing_util_push_log_hook ("*assertion*G_TYPE_IS_INTERFACE*failed");
-  testing_util_push_log_hook ("*type 'PeasActivatable' has no property named 'invalid-property'");
+  testing_util_push_log_hook ("*type 'IntrospectionActivatable' has no property named 'invalid-property'");
 
   /* Invalid GType */
   extension_set = peas_extension_set_new (engine, G_TYPE_INVALID, NULL);
@@ -209,7 +216,7 @@ test_extension_set_create_invalid (PeasEngine *engine)
 
   /* Interface does not have an 'invalid-property' property */
   extension_set = peas_extension_set_new (engine,
-                                          PEAS_TYPE_ACTIVATABLE,
+                                          INTROSPECTION_TYPE_ACTIVATABLE,
                                           "invalid-property", "does-not-exist",
                                           NULL);
   g_assert (!PEAS_IS_EXTENSION_SET (extension_set));
@@ -220,8 +227,8 @@ test_extension_set_create_invalid_with_properties (PeasEngine *engine)
 {
   PeasExtensionSet *extension_set;
   GValue prop_values[2] = { G_VALUE_INIT };
-  const gchar *prop_names[2] = { "object", NULL };
-  const gchar *prop_names_not_exist[1] = { "aleb" };
+  const char *prop_names[2] = { "object", NULL };
+  const char *prop_names_not_exist[1] = { "aleb" };
   guint n_elements;
 
   testing_util_push_log_hook ("*property name*should not be NULL.");
@@ -235,7 +242,7 @@ test_extension_set_create_invalid_with_properties (PeasEngine *engine)
   /* Interface has a NULL property name*/
   n_elements = G_N_ELEMENTS (prop_values);
   extension_set = peas_extension_set_new_with_properties (engine,
-                                                          PEAS_TYPE_ACTIVATABLE,
+                                                          INTROSPECTION_TYPE_ACTIVATABLE,
                                                           n_elements,
                                                           prop_names,
                                                           prop_values);
@@ -251,7 +258,7 @@ test_extension_set_create_invalid_with_properties (PeasEngine *engine)
   /* Uninitialized GValue */
   n_elements = 1;
   extension_set = peas_extension_set_new_with_properties (engine,
-                                                          PEAS_TYPE_ACTIVATABLE,
+                                                          INTROSPECTION_TYPE_ACTIVATABLE,
                                                           n_elements,
                                                           prop_names,
                                                           prop_values);
@@ -262,7 +269,7 @@ test_extension_set_create_invalid_with_properties (PeasEngine *engine)
   g_value_set_pointer (&prop_values[0], NULL);
   n_elements = G_N_ELEMENTS (prop_names_not_exist);
   extension_set = peas_extension_set_new_with_properties (engine,
-                                                          PEAS_TYPE_ACTIVATABLE,
+                                                          INTROSPECTION_TYPE_ACTIVATABLE,
                                                           n_elements,
                                                           prop_names_not_exist,
                                                           prop_values);
@@ -274,7 +281,7 @@ test_extension_set_create_invalid_with_properties (PeasEngine *engine)
 static void
 test_extension_set_extension_added (PeasEngine *engine)
 {
-  gint active;
+  int active;
   PeasExtensionSet *extension_set;
 
   /* This will check that an extension is added
@@ -282,7 +289,7 @@ test_extension_set_extension_added (PeasEngine *engine)
    * be synced with the number of added extensions
    */
   extension_set = testing_extension_set_new (engine, &active);
-  
+
   g_object_unref (extension_set);
 
   /* Verify that freeing the extension
@@ -294,13 +301,13 @@ test_extension_set_extension_added (PeasEngine *engine)
 static void
 test_extension_set_extension_removed (PeasEngine *engine)
 {
-  gint i, active;
+  int i, active;
   PeasPluginInfo *info;
   PeasExtensionSet *extension_set;
 
   extension_set = testing_extension_set_new (engine, &active);
 
-  /* Unload the plugin that does not provide a PeasActivatable */
+  /* Unload the plugin that does not provide a IntrospectionActivatable */
   info = peas_engine_get_plugin_info (engine, "extension-c");
   g_assert (peas_engine_unload_plugin (engine, info));
 
@@ -323,14 +330,14 @@ static void
 test_extension_set_get_extension (PeasEngine *engine)
 {
   PeasPluginInfo *info;
-  PeasExtension *extension;
+  GObject *extension;
   PeasExtensionSet *extension_set;
 
   extension_set = testing_extension_set_new (engine, NULL);
   info = peas_engine_get_plugin_info (engine, loadable_plugins[0]);
 
   extension = peas_extension_set_get_extension (extension_set, info);
-  g_assert (PEAS_IS_ACTIVATABLE (extension));
+  g_assert (INTROSPECTION_IS_ACTIVATABLE (extension));
 
   g_object_add_weak_pointer (G_OBJECT (extension),
                              (gpointer) &extension);
@@ -342,36 +349,10 @@ test_extension_set_get_extension (PeasEngine *engine)
   g_object_unref (extension_set);
 }
 
-static void
-test_extension_set_call_valid (PeasEngine *engine)
-{
-  PeasExtensionSet *extension_set;
-
-  extension_set = testing_extension_set_new (engine, NULL);
-
-  g_assert (peas_extension_set_call (extension_set, "activate", NULL));
-
-  g_object_unref (extension_set);
-}
-
-static void
-test_extension_set_call_invalid (PeasEngine *engine)
-{
-  PeasExtensionSet *extension_set;
-
-  testing_util_push_log_hook ("Method 'PeasActivatable.invalid' was not found");
-
-  extension_set = testing_extension_set_new (engine, NULL);
-
-  g_assert (!peas_extension_set_call (extension_set, "invalid", NULL));
-
-  g_object_unref (extension_set);
-}
-
 static void
 test_extension_set_foreach (PeasEngine *engine)
 {
-  gint count = 0;
+  int count = 0;
   PeasExtensionSet *extension_set;
 
   extension_set = testing_extension_set_new (engine, NULL);
@@ -388,10 +369,10 @@ test_extension_set_foreach (PeasEngine *engine)
 static void
 ordering_cb (PeasExtensionSet  *set,
              PeasPluginInfo    *info,
-             PeasExtension     *extension,
+             GObject           *extension,
              GList            **order)
 {
-  const gchar *order_module_name = (const gchar *) (*order)->data;
+  const char *order_module_name = (const char *) (*order)->data;
 
   g_assert_cmpstr (order_module_name, ==,
                    peas_plugin_info_get_module_name (info));
@@ -452,9 +433,6 @@ main (int    argc,
 
   TEST ("get-extension", get_extension);
 
-  TEST ("call-valid", call_valid);
-  TEST ("call-invalid", call_invalid);
-
   TEST ("foreach", foreach);
 
   TEST ("ordering", ordering);
