@@ -17,12 +17,13 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef __INTROSPECTION_ABSTRACT_H__
-#define __INTROSPECTION_ABSTRACT_H__
+#pragma once
 
-#include <libpeas/peas.h>
+#include <libpeas.h>
 
 #include "../../testing-util/peas-test-common.h"
 
@@ -56,12 +57,10 @@ GType  introspection_abstract_get_type  (void) G_GNUC_CONST;
 
 
 PEAS_TEST_EXPORT
-gint   introspection_abstract_get_value (IntrospectionAbstract *abstract);
+int    introspection_abstract_get_value (IntrospectionAbstract *abstract);
 
 PEAS_TEST_EXPORT
 void   introspection_abstract_set_value (IntrospectionAbstract *abstract,
-                                         gint                   value);
+                                         int                    value);
 
 G_END_DECLS
-
-#endif /* __INTROSPECTION_ABSTRACT_H__ */
