@@ -17,11 +17,11 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include "introspection-callable.h"
 
@@ -38,7 +38,7 @@ introspection_callable_default_init (IntrospectionCallableInterface *iface)
  *
  * Returns: (transfer full):
  */
-gchar *
+char *
 introspection_callable_call_with_return (IntrospectionCallable *callable)
 {
   IntrospectionCallableInterface *iface;
@@ -96,9 +96,9 @@ introspection_callable_call_single_arg (IntrospectionCallable *callable,
  */
 void
 introspection_callable_call_multi_args (IntrospectionCallable *callable,
-                                        gint                   in,
-                                        gint                  *out,
-                                        gint                  *inout)
+                                        int                    in,
+                                        int                   *out,
+                                        int                   *inout)
 {
   IntrospectionCallableInterface *iface;
 
