@@ -17,16 +17,16 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include <stdlib.h>
 
 #include <glib.h>
-#include <libpeas/peas.h>
+#include <libpeas.h>
 
 #include "testing/testing.h"
 
@@ -62,7 +62,7 @@ test_plugin_info_verify_full_info (PeasEngine *engine)
 {
   PeasPluginInfo *info;
   GError *error = NULL;
-  const gchar **authors;
+  const char * const *authors;
 
   info = peas_engine_get_plugin_info (engine, "full-info");
 
@@ -93,6 +93,18 @@ test_plugin_info_verify_full_info (PeasEngine *engine)
 
   g_assert_cmpstr (peas_plugin_info_get_external_data (info, "External"), ==, "external data");
   g_assert_cmpstr (peas_plugin_info_get_external_data (info, "X-External"), ==, "external data");
+
+  {
+    static const char *strprops[] = { "name", "description", "icon-name", "website", "copyright", "version", "help-uri", NULL };
+
+    for (guint i = 0; strprops[i]; i++)
+      {
+        char *str = NULL;
+        g_object_get (info, strprops[i], &str, NULL);
+        g_assert_nonnull (str);
+        g_free (str);
+      }
+  }
 }
 
 static void
@@ -100,7 +112,7 @@ test_plugin_info_verify_min_info (PeasEngine *engine)
 {
   PeasPluginInfo *info;
   GError *error = NULL;
-  const gchar **authors;
+  const char * const *authors;
 
   info = peas_engine_get_plugin_info (engine, "min-info");
 
@@ -161,7 +173,7 @@ static void
 test_plugin_info_os_dependant_help (PeasEngine *engine)
 {
   PeasPluginInfo *info;
-  const gchar *help;
+  const char *help;
 
   info = peas_engine_get_plugin_info (engine, "os-dependant-help");
 
