@@ -17,23 +17,24 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 
 #include <glib.h>
-#include <libpeas/peas.h>
+#include <libpeas.h>
 
 #include "testing.h"
 #include "testing-extension.h"
 
 #include "introspection-abstract.h"
+#include "introspection-activatable.h"
 #include "introspection-base.h"
 #include "introspection-callable.h"
 #include "introspection-has-prerequisite.h"
@@ -46,8 +47,8 @@ struct _TestFixture {
   PeasPluginInfo *info;
 };
 
-static gchar *loader = NULL;
-static gchar *extension_plugin = NULL;
+static char *loader = NULL;
+static char *extension_plugin = NULL;
 
 static void
 test_setup (TestFixture    *fixture,
@@ -81,14 +82,14 @@ static void
 test_extension_garbage_collect (PeasEngine     *engine,
                                 PeasPluginInfo *info)
 {
-  gchar **loaded_plugins;
+  char **loaded_plugins;
 
   peas_engine_garbage_collect (engine);
 
   /* Check that we can collect the garbage when no plugins are loaded */
   g_assert (peas_engine_unload_plugin (engine, info));
 
-  loaded_plugins = peas_engine_get_loaded_plugins (engine);
+  loaded_plugins = peas_engine_dup_loaded_plugins (engine);
   g_assert_cmpstr (loaded_plugins[0], ==, NULL);
   g_strfreev (loaded_plugins);
 
@@ -132,13 +133,13 @@ static void
 test_extension_create_valid (PeasEngine     *engine,
                              PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
 
   extension = peas_engine_create_extension (engine, info,
                                             INTROSPECTION_TYPE_CALLABLE,
                                             NULL);
 
-  g_assert (PEAS_IS_EXTENSION (extension));
+  g_assert (G_IS_OBJECT (extension));
   g_assert (INTROSPECTION_IS_CALLABLE (extension));
 
   g_object_unref (extension);
@@ -148,14 +149,14 @@ static void
 test_extension_create_valid_without_properties (PeasEngine     *engine,
                                                 PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
 
   extension =
     peas_engine_create_extension_with_properties (engine, info,
                                                   INTROSPECTION_TYPE_CALLABLE,
                                                   0, NULL, NULL);
 
-  g_assert (PEAS_IS_EXTENSION (extension));
+  g_assert (G_IS_OBJECT (extension));
   g_assert (INTROSPECTION_IS_CALLABLE (extension));
 
   g_object_unref (extension);
@@ -165,10 +166,10 @@ static void
 test_extension_create_valid_with_properties (PeasEngine     *engine,
                                              PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
   IntrospectionAbstract *abstract;
   GValue prop_values[1] = { G_VALUE_INIT };
-  const gchar *prop_names[1] = { "abstract-property" };
+  const char *prop_names[1] = { "abstract-property" };
 
   g_assert (peas_engine_load_plugin (engine, info));
 
@@ -191,7 +192,7 @@ static void
 test_extension_create_invalid (PeasEngine     *engine,
                                PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
 
   testing_util_push_log_hook ("*assertion*G_TYPE_IS_INTERFACE*failed");
   testing_util_push_log_hook ("*does not provide a 'IntrospectionUnimplemented' extension");
@@ -200,44 +201,44 @@ test_extension_create_invalid (PeasEngine     *engine,
 
   /* Invalid GType */
   extension = peas_engine_create_extension (engine, info, G_TYPE_INVALID, NULL);
-  g_assert (!PEAS_IS_EXTENSION (extension));
+  g_assert (!G_IS_OBJECT (extension));
 
 
   /* GObject but not a GInterface */
   extension = peas_engine_create_extension (engine, info, PEAS_TYPE_ENGINE, NULL);
-  g_assert (!PEAS_IS_EXTENSION (extension));
+  g_assert (!G_IS_OBJECT (extension));
 
 
   /* Does not implement this GType */
   extension = peas_engine_create_extension (engine, info,
                                             INTROSPECTION_TYPE_UNIMPLEMENTED,
                                             NULL);
-  g_assert (!PEAS_IS_EXTENSION (extension));
+  g_assert (!G_IS_OBJECT (extension));
 
   /* Interface does not have a specified property */
   extension = peas_engine_create_extension (engine, info,
                                             INTROSPECTION_TYPE_CALLABLE,
                                             "does-not-exist", "",
                                             NULL);
-  g_assert (!PEAS_IS_EXTENSION (extension));
+  g_assert (!G_IS_OBJECT (extension));
 
   /* Not loaded */
   g_assert (peas_engine_unload_plugin (engine, info));
   extension = peas_engine_create_extension (engine, info,
                                             INTROSPECTION_TYPE_CALLABLE,
                                             NULL);
-  g_assert (!PEAS_IS_EXTENSION (extension));
+  g_assert (!G_IS_OBJECT (extension));
 }
 
 static void
 test_extension_create_invalid_with_properties (PeasEngine     *engine,
                                                PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
   GValue prop_values[1] = { G_VALUE_INIT };
-  const gchar *prop_names[1] = { NULL };
+  const char *prop_names[1] = { NULL };
   GValue prop_values2[1] = { G_VALUE_INIT };
-  const gchar *prop_names2[1] = { "does-not-exist" };
+  const char *prop_names2[1] = { "does-not-exist" };
 
   g_value_init (&prop_values[0], G_TYPE_STRING);
   g_value_set_string (&prop_values[0], "foo");
@@ -252,20 +253,20 @@ test_extension_create_invalid_with_properties (PeasEngine     *engine,
   extension = peas_engine_create_extension_with_properties (engine, info,
                                                             G_TYPE_INVALID, 0,
                                                             NULL, NULL);
-  g_assert (!PEAS_IS_EXTENSION (extension));
+  g_assert (!G_IS_OBJECT (extension));
 
   /* GObject but not a GInterface */
   extension = peas_engine_create_extension_with_properties (engine, info,
                                                             PEAS_TYPE_ENGINE, 0,
                                                             NULL, NULL);
-  g_assert (!PEAS_IS_EXTENSION (extension));
+  g_assert (!G_IS_OBJECT (extension));
 
   /* Does not implement this GType */
   extension =
     peas_engine_create_extension_with_properties (engine, info,
                                                   INTROSPECTION_TYPE_UNIMPLEMENTED,
                                                   0, NULL, NULL);
-  g_assert (!PEAS_IS_EXTENSION (extension));
+  g_assert (!G_IS_OBJECT (extension));
 
   /* Interface has a NULL property name*/
   extension =
@@ -273,7 +274,7 @@ test_extension_create_invalid_with_properties (PeasEngine     *engine,
                                                   INTROSPECTION_TYPE_CALLABLE,
                                                   G_N_ELEMENTS (prop_names2),
                                                   prop_names, prop_values);
-  g_assert (!PEAS_IS_EXTENSION (extension));
+  g_assert (!G_IS_OBJECT (extension));
 
   /* Interface has a not initialiazed GValue */
   extension =
@@ -281,7 +282,7 @@ test_extension_create_invalid_with_properties (PeasEngine     *engine,
                                                   INTROSPECTION_TYPE_CALLABLE,
                                                   G_N_ELEMENTS (prop_names2),
                                                   prop_names2, prop_values2);
-  g_assert (!PEAS_IS_EXTENSION (extension));
+  g_assert (!G_IS_OBJECT (extension));
 
   /* Not loaded */
   g_assert (peas_engine_unload_plugin (engine, info));
@@ -289,7 +290,7 @@ test_extension_create_invalid_with_properties (PeasEngine     *engine,
     peas_engine_create_extension_with_properties (engine, info,
                                                   INTROSPECTION_TYPE_CALLABLE,
                                                   0, NULL, NULL);
-  g_assert (!PEAS_IS_EXTENSION (extension));
+  g_assert (!G_IS_OBJECT (extension));
 
   g_value_unset (&prop_values[0]);
 
@@ -299,8 +300,8 @@ static void
 test_extension_create_with_prerequisite (PeasEngine     *engine,
                                          PeasPluginInfo *info)
 {
-  PeasExtension *extension;
-  gint prerequisite_property = -1;
+  GObject *extension;
+  int prerequisite_property = -1;
 
   extension = peas_engine_create_extension (engine, info,
                                             INTROSPECTION_TYPE_HAS_PREREQUISITE,
@@ -322,7 +323,7 @@ static void
 test_extension_reload (PeasEngine     *engine,
                        PeasPluginInfo *info)
 {
-  gint i;
+  int i;
 
   for (i = 0; i < 3; ++i)
     {
@@ -335,7 +336,7 @@ static void
 test_extension_plugin_info (PeasEngine     *engine,
                             PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
   IntrospectionBase *base;
 
   g_assert (peas_engine_load_plugin (engine, info));
@@ -355,7 +356,7 @@ static void
 test_extension_get_settings (PeasEngine     *engine,
                              PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
   IntrospectionBase *base;
   GSettings *settings;
 
@@ -368,7 +369,8 @@ test_extension_get_settings (PeasEngine     *engine,
   base = INTROSPECTION_BASE (extension);
 
   settings = introspection_base_get_settings (base);
-  g_assert (G_IS_SETTINGS (settings));
+  g_assert_nonnull (settings);
+  g_assert_true (G_IS_SETTINGS (settings));
 
   g_object_unref (settings);
   g_object_unref (extension);
@@ -378,7 +380,7 @@ static void
 test_extension_abstract (PeasEngine     *engine,
                          PeasPluginInfo *info)
 {
-  PeasExtension *extension;
+  GObject *extension;
   IntrospectionAbstract *abstract;
 
   g_assert (peas_engine_load_plugin (engine, info));
@@ -397,11 +399,11 @@ test_extension_abstract (PeasEngine     *engine,
   g_object_unref (extension);
 }
 
-static gint
+static int
 run_in_multiple_threads (GFunc    func,
                          gpointer user_data)
 {
-  gint i, n_threads;
+  int i, n_threads;
   GThreadPool *pool;
   GError *error = NULL;
 
@@ -427,7 +429,7 @@ static void
 multiple_threads_loaders_in_thread (guint    nth_thread,
                                     gboolean use_nonglobal_loaders)
 {
-  gint i, j;
+  int i, j;
   PeasEngine *engine;
   PeasPluginInfo *info;
   GObject *extension;
@@ -475,24 +477,24 @@ test_extension_multiple_threads_nonglobal_loaders (PeasEngine     *engine,
 }
 
 static void
-multiple_threads_callbacks_in_thread (guint            nth_thread,
-                                      PeasActivatable *activatable)
+multiple_threads_callbacks_in_thread (guint                     nth_thread,
+                                      IntrospectionActivatable *activatable)
 {
-  gint i;
+  int i;
 
   for (i = 0; i < 100; ++i)
-    peas_activatable_update_state (activatable);
+    introspection_activatable_update_state (activatable);
 }
 
 static void
 test_extension_multiple_threads_callbacks (PeasEngine     *engine,
                                            PeasPluginInfo *info)
 {
-  PeasExtension *extension;
-  gint n_threads, update_count;
+  GObject *extension;
+  int n_threads, update_count;
 
   extension = peas_engine_create_extension (engine, info,
-                                            PEAS_TYPE_ACTIVATABLE,
+                                            INTROSPECTION_TYPE_ACTIVATABLE,
                                             NULL);
 
   n_threads = run_in_multiple_threads ((GFunc) multiple_threads_callbacks_in_thread,
@@ -504,160 +506,28 @@ test_extension_multiple_threads_callbacks (PeasEngine     *engine,
   g_object_unref (extension);
 }
 
-static void
-test_extension_call_no_args (PeasEngine     *engine,
-                             PeasPluginInfo *info)
-{
-  PeasExtension *extension;
-  IntrospectionCallable *callable;
-
-  extension = peas_engine_create_extension (engine, info,
-                                            INTROSPECTION_TYPE_CALLABLE,
-                                            NULL);
-
-  callable = INTROSPECTION_CALLABLE (extension);
-
-  g_assert (peas_extension_call (extension, "call_no_args"));
-  introspection_callable_call_no_args (callable);
-
-  g_object_unref (extension);
-}
-
-static void
-test_extension_call_with_return (PeasEngine     *engine,
-                                 PeasPluginInfo *info)
-{
-  PeasExtension *extension;
-  IntrospectionCallable *callable;
-  gchar *return_val = NULL;
-
-  extension = peas_engine_create_extension (engine, info,
-                                            INTROSPECTION_TYPE_CALLABLE,
-                                            NULL);
-
-  callable = INTROSPECTION_CALLABLE (extension);
-
-  g_assert (peas_extension_call (extension, "call_with_return", &return_val));
-  g_assert_cmpstr (return_val, ==, "Hello, World!");
-
-  g_free (return_val);
-  return_val = NULL;
-
-  return_val = introspection_callable_call_with_return (callable);
-  g_assert_cmpstr (return_val, ==, "Hello, World!");
-
-  g_free (return_val);
-  g_object_unref (extension);
-}
-
-static void
-test_extension_call_single_arg (PeasEngine     *engine,
-                                PeasPluginInfo *info)
-{
-  PeasExtension *extension;
-  IntrospectionCallable *callable;
-  gboolean called = FALSE;
-
-  extension = peas_engine_create_extension (engine, info,
-                                            INTROSPECTION_TYPE_CALLABLE,
-                                            NULL);
-
-  callable = INTROSPECTION_CALLABLE (extension);
-
-  g_assert (peas_extension_call (extension, "call_single_arg", &called));
-  g_assert (called);
-
-  called = FALSE;
-
-  introspection_callable_call_single_arg (callable, &called);
-  g_assert (called);
-
-  g_object_unref (extension);
-}
-
-static void
-test_extension_call_multi_args (PeasEngine     *engine,
-                                PeasPluginInfo *info)
-{
-  PeasExtension *extension;
-  IntrospectionCallable *callable;
-  gint in, out, inout;
-  gint inout_saved;
-
-  extension = peas_engine_create_extension (engine, info,
-                                            INTROSPECTION_TYPE_CALLABLE,
-                                            NULL);
-
-  callable = INTROSPECTION_CALLABLE (extension);
-
-  in = g_random_int ();
-  inout = g_random_int ();
-  inout_saved = inout;
-
-  g_assert (peas_extension_call (extension, "call_multi_args",
-                                 in, &out, &inout));
-
-  g_assert_cmpint (inout_saved, ==, out);
-  g_assert_cmpint (in, ==, inout);
-
-  in = g_random_int ();
-  inout = g_random_int ();
-  inout_saved = inout;
-
-  introspection_callable_call_multi_args (callable, in, &out, &inout);
-
-  g_assert_cmpint (inout_saved, ==, out);
-  g_assert_cmpint (in, ==, inout);
-
-  g_object_unref (extension);
-}
-
-static void
-test_extension_call_abstract (PeasEngine     *engine,
-                              PeasPluginInfo *info)
-{
-  PeasExtension *extension;
-  gint value = 0;
-
-  g_assert (peas_engine_load_plugin (engine, info));
-
-  extension = peas_engine_create_extension (engine, info,
-                                            INTROSPECTION_TYPE_ABSTRACT,
-                                            "abstract-property", 47,
-                                            NULL);
-
-  g_assert (peas_extension_call (extension, "get_value", &value));
-  g_assert_cmpint (value, ==, 47);
-
-  g_assert (peas_extension_call (extension, "set_value", -22));
-  g_assert (peas_extension_call (extension, "get_value", &value));
-  g_assert_cmpint (value, ==, -22);
-
-  g_object_unref (extension);
-}
-
 #define _EXTENSION_TEST(loader, path, ftest) \
   G_STMT_START { \
-    gchar *full_path = g_strdup_printf (EXTENSION_TEST_NAME (%s, "%s"), \
-                                        loader, path); \
-\
-    g_test_add (full_path, TestFixture, \
-                (gpointer) test_extension_##ftest, \
-                test_setup, test_runner, test_teardown); \
-\
-    g_free (full_path); \
+    char *full_path = g_strdup_printf (EXTENSION_TEST_NAME (%s, "%s"), \
+                                       loader, path);                  \
+                                                                       \
+    g_test_add (full_path, TestFixture,                                \
+                (gpointer) test_extension_##ftest,                     \
+                test_setup, test_runner, test_teardown);               \
+                                                                       \
+    g_free (full_path);                                                \
   } G_STMT_END
 
 void
-testing_extension_basic (const gchar *loader_)
+testing_extension_basic (const char *loader_)
 {
-  gint i, j;
-  gchar *loader_name;
+  int i, j;
+  char *loader_name;
   PeasEngine *engine;
 
   loader = g_strdup (loader_);
 
-  loader_name = g_new0 (gchar, strlen (loader) + 1);
+  loader_name = g_new0 (char, strlen (loader) + 1);
   for (i = 0, j = 0; loader[i] != '\0'; ++i)
     {
       if (loader[i] != '.')
@@ -698,13 +568,16 @@ testing_extension_basic (const gchar *loader_)
 
   _EXTENSION_TEST (loader, "abstract", abstract);
 
-  _EXTENSION_TEST (loader, "multiple-threads/global-loaders",
-                   multiple_threads_global_loaders);
-  _EXTENSION_TEST (loader, "multiple-threads/nonglobal-loaders",
-                   multiple_threads_nonglobal_loaders);
+  if (g_strcmp0 (loader, "gjs") != 0)
+    {
+      _EXTENSION_TEST (loader, "multiple-threads/global-loaders",
+                       multiple_threads_global_loaders);
+      _EXTENSION_TEST (loader, "multiple-threads/nonglobal-loaders",
+                       multiple_threads_nonglobal_loaders);
+    }
 
   /* Not needed for C plugins as they are independent of libpeas */
-  if (g_strcmp0 (loader, "c") != 0)
+  if (g_strcmp0 (loader, "c") != 0 && g_strcmp0 (loader, "gjs") != 0)
     {
       _EXTENSION_TEST (loader, "multiple-threads/callbacks",
                        multiple_threads_callbacks);
@@ -712,17 +585,7 @@ testing_extension_basic (const gchar *loader_)
 }
 
 void
-testing_extension_callable (const gchar *loader)
-{
-  _EXTENSION_TEST (loader, "call-no-args", call_no_args);
-  _EXTENSION_TEST (loader, "call-with-return", call_with_return);
-  _EXTENSION_TEST (loader, "call-single-arg", call_single_arg);
-  _EXTENSION_TEST (loader, "call-multi-args", call_multi_args);
-  _EXTENSION_TEST (loader, "call-abstract", call_abstract);
-}
-
-void
-testing_extension_add (const gchar   *path,
+testing_extension_add (const char    *path,
                        GTestDataFunc  func)
 {
   g_test_add (path, TestFixture, (gpointer) func,
