@@ -17,10 +17,11 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifndef __TESTING_H__
-#define __TESTING_H__
+#pragma once
 
 #include <libpeas/peas-engine.h>
 #include <testing-util.h>
@@ -28,8 +29,8 @@
 G_BEGIN_DECLS
 
 PEAS_TEST_EXPORT
-void        testing_init             (gint    *argc,
-                                      gchar ***argv);
+void        testing_init             (int    *argc,
+                                      char ***argv);
 
 PEAS_TEST_EXPORT
 PeasEngine *testing_engine_new_full  (gboolean nonglobal_loaders);
@@ -41,5 +42,3 @@ PeasEngine *testing_engine_new_full  (gboolean nonglobal_loaders);
 #define testing_run_tests   testing_util_run_tests
 
 G_END_DECLS
-
-#endif /* __TESTING_H__ */
