@@ -17,6 +17,8 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "config.h"
@@ -24,14 +26,14 @@
 #include <stdlib.h>
 
 #include <glib.h>
-#include <girepository/girepository.h>
+#include <girepository.h>
 
 #include "libpeas/peas-engine-priv.h"
 
 #include "testing-util.h"
 
 typedef struct {
-  const gchar *pattern;
+  const char *pattern;
   gboolean hit;
 } LogHook;
 
@@ -104,9 +106,9 @@ get_log_hooks (void)
 }
 
 static void
-log_handler (const gchar    *log_domain,
+log_handler (const char     *log_domain,
              GLogLevelFlags  log_level,
-             const gchar    *message,
+             const char     *message,
              gpointer        user_data)
 {
   LogHooks *log_hooks = get_log_hooks ();
@@ -134,7 +136,7 @@ log_handler (const gchar    *log_domain,
   for (i = 0; i < hooks->len; ++i)
     {
       LogHook *hook = g_ptr_array_index (hooks, i);
-      gchar *msg;
+      char *msg;
 
       if (!g_pattern_match_simple (hook->pattern, message))
         continue;
@@ -187,7 +189,6 @@ void
 testing_util_init (void)
 {
   GError *error = NULL;
-  GIRepository *repository;
   const GDebugKey glib_debug_keys[] = {
     { "fatal-criticals", G_LOG_LEVEL_CRITICAL },
     { "fatal-warnings",  G_LOG_LEVEL_CRITICAL | G_LOG_LEVEL_WARNING }
@@ -208,12 +209,10 @@ testing_util_init (void)
   fatal_flags = g_parse_debug_string (g_getenv ("G_DEBUG"), glib_debug_keys,
                                       G_N_ELEMENTS (glib_debug_keys));
 
-  repository = gi_repository_dup_default ();
-  gi_repository_require_private (repository,
+  g_irepository_require_private (g_irepository_get_default (),
                                  BUILDDIR "/libpeas",
-                                 "Peas", "1.0", 0, &error);
+                                 "Peas", API_VERSION_S, 0, &error);
   g_assert_no_error (error);
-  g_clear_object (&repository);
 
   initialized = TRUE;
 }
@@ -307,7 +306,7 @@ testing_util_run_tests (void)
 }
 
 void
-testing_util_push_log_hook (const gchar *pattern)
+testing_util_push_log_hook (const char *pattern)
 {
   LogHooks *log_hooks = get_log_hooks ();
   LogHook *hook;
@@ -403,7 +402,7 @@ testing_util_pop_log_hooks (void)
 
       for (i = 0; i < hits->len; ++i)
         {
-          const gchar *hit = g_ptr_array_index (hits, i);
+          const char *hit = g_ptr_array_index (hits, i);
 
           g_string_append_printf (msg, "\n\t%s", hit);
         }
